# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: media_app/grpc/media_app.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1emedia_app/grpc/media_app.proto\x12\x11\x64\x61rsman.media_app\x1a\x1cgoogle/protobuf/struct.proto\"+\n\x18MediaBulkRetrieveRequest\x12\x0f\n\x07uuid_id\x18\x01 \x03(\t\"\'\n\x14MediaRetrieveRequest\x12\x0f\n\x07uuid_id\x18\x01 \x01(\t\"o\n\x08Response\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x02 \x01(\tH\x01\x88\x01\x01\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\n\n\x08_messageB\x07\n\x05_code2\xc1\x01\n\x0fMediaController\x12Z\n\x0c\x42ulkRetrieve\x12+.darsman.media_app.MediaBulkRetrieveRequest\x1a\x1b.darsman.media_app.Response\"\x00\x12R\n\x08Retrieve\x12\'.darsman.media_app.MediaRetrieveRequest\x1a\x1b.darsman.media_app.Response\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'media_app.grpc.media_app_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MEDIABULKRETRIEVEREQUEST']._serialized_start=83
  _globals['_MEDIABULKRETRIEVEREQUEST']._serialized_end=126
  _globals['_MEDIARETRIEVEREQUEST']._serialized_start=128
  _globals['_MEDIARETRIEVEREQUEST']._serialized_end=167
  _globals['_RESPONSE']._serialized_start=169
  _globals['_RESPONSE']._serialized_end=280
  _globals['_MEDIACONTROLLER']._serialized_start=283
  _globals['_MEDIACONTROLLER']._serialized_end=476
# @@protoc_insertion_point(module_scope)



from dmmc.grpc.media_app_pb2 import MediaBulkRetrieveRequest, MediaRetrieveRequest
from dmmc.grpc.media_app_pb2_grpc import MediaControllerStub

SUCCESS_CODE = "0"


def _singletonize_class_vars(cls):
    for attr_name, attr_value in cls.__dict__.items():
        if isinstance(attr_value, type):  # it's a class
            orig_cls = attr_value

            class SingletonWrapper(orig_cls):
                _instances = {}

                def __new__(cls, *args, **kwargs):
                    if cls not in cls._instances:
                        cls._instances[cls] = super().__new__(cls)
                    return cls._instances[cls]

            setattr(cls, attr_name, SingletonWrapper)
    return cls


class RequestMessages:
    FETCH_ONE_MEDIA = MediaRetrieveRequest
    FETCH_BULK_MEDIA = MediaBulkRetrieveRequest


class RPCMethodNames:
    FETCH_ONE = "Retrieve"
    FETCH_BULK = "BulkRetrieve"


@_singletonize_class_vars
class Stubs:
    MEDIA = MediaControllerStub
